# databroker


A unified interface to the various data sources at NSLS-II.


[Databroker documentation](http://nsls-ii.github.io/databroker)

[NSLS2 software overview](http://nsls-ii.github.io)

---------------

[![Build Status](https://travis-ci.org/bluesky/databroker.svg?branch=master)](https://travis-ci.org/bluesky/databroker)
[![codecov](https://codecov.io/gh/bluesky/databroker/branch/master/graph/badge.svg)](https://codecov.io/gh/bluesky/databroker)
[![Anaconda-Server Badge](https://anaconda.org/lightsource2/databroker/badges/version.svg)](https://anaconda.org/lightsource2/databroker)
[![Anaconda-Server Badge](https://anaconda.org/lightsource2/databroker/badges/license.svg)](https://anaconda.org/lightsource2/databroker)

## Conda Recipes

Install the most recent tagged build: `conda install databroker -c lightsource2-tag`

Install the most recent tagged build: `conda install databroker -c lightsource2-dev`

Find the tagged recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-tag/databroker) and the dev recipe [here](https://github.com/NSLS-II/lightsource2-recipes/tree/master/recipes-dev/databroker)
